@@ -18,15 +18,11 @@ import logging
 
 from keystoneauth1 import exceptions as ks_exc
 from keystoneauth1 import session as ks_session
-from keystoneauth1 import token_endpoint
-from oslo_utils import netutils
 import requests
-import six
 
-from ironic_inspector_client.common.i18n import _, _LW
+from ironic_inspector_client.common.i18n import _
 
 
-_DEFAULT_URL = 'http://' + netutils.get_my_ipv4() + ':5050'
 _ERROR_ENCODING = 'utf-8'
 LOG = logging.getLogger('ironic_inspector_client')
 
@@ -51,12 +47,31 @@ class ClientError(requests.HTTPError):
         # inspector returns error message in body
         msg = response.content.decode(_ERROR_ENCODING)
         try:
-            msg = json.loads(msg)['error']['message']
+            msg = json.loads(msg)
         except ValueError:
             LOG.debug('Old style error response returned, assuming '
                       'ironic-discoverd')
-        except (KeyError, TypeError):
+        except TypeError:
             LOG.exception('Bad error response from Ironic Inspector')
+        else:
+            try:
+                msg = msg['error']['message']
+            except KeyError as exc:
+                LOG.error('Invalid error response from Ironic Inspector: '
+                          '%(msg)s (missing key %(key)s)',
+                          {'msg': msg, 'key': exc})
+                # It's surprisingly common to try accessing ironic URL with
+                # ironic-inspector-client, handle this case
+                try:
+                    msg = msg['error_message']
+                except KeyError:
+                    pass
+                else:
+                    msg = _('Received Ironic-style response %s. Are you '
+                            'trying to access Ironic URL instead of Ironic '
+                            'Inspector?') % msg
+            except TypeError:
+                LOG.exception('Bad error response from Ironic Inspector')
 
         LOG.debug('Inspector returned error "%(msg)s" (HTTP %(code)s)',
                   {'msg': msg, 'code': response.status_code})
@@ -70,7 +85,12 @@ class ClientError(requests.HTTPError):
 
 
 class VersionNotSupported(Exception):
-    """Denotes that requested API versions is not supported by the server."""
+    """Denotes that requested API versions is not supported by the server.
+
+    :ivar expected: requested version.
+    :ivar supported: sequence with two items: minimum and maximum actually
+        supported versions.
+    """
     def __init__(self, expected, supported):
         msg = (_('Version %(expected)s is not supported by the server, '
                  'supported range is %(supported)s') %
@@ -81,10 +101,23 @@ class VersionNotSupported(Exception):
         super(Exception, self).__init__(msg)
 
 
+class EndpointNotFound(Exception):
+    """Denotes that endpoint for the introspection service was not found.
+
+    :ivar service_type: requested service type
+    """
+
+    def __init__(self, service_type):
+        self.service_type = service_type
+        msg = _('Endpoint of type %s was not found in the service catalog '
+                'and was not provided explicitly') % service_type
+        super(Exception, self).__init__(msg)
+
+
 class BaseClient(object):
     """Base class for clients, provides common HTTP code."""
 
-    def __init__(self, api_version, inspector_url=None, auth_token=None,
+    def __init__(self, api_version, inspector_url=None,
                  session=None, service_type='baremetal-introspection',
                  interface=None, region_name=None):
         """Create a client.
@@ -95,26 +128,20 @@ class BaseClient(object):
             http://host:port[/ver]. When session is provided, defaults to
             service URL from the catalog. As a last resort
             defaults to ``http://<current host>:5050/v<MAJOR>``.
-        :param auth_token: authentication token (deprecated, use session)
-        :param session: existing keystone session
+        :param session: existing keystone session. A session without
+            authentication is created if this is set to None.
         :param service_type: service type to use when looking up the URL
         :param interface: interface type (public, internal, etc) to use when
             looking up the URL
         :param region_name: region name to use when looking up the URL
+        :raises: EndpointNotFound if the introspection service endpoint
+            was not provided via inspector_url and was not found in the
+            service catalog.
         """
-        self._base_url = inspector_url or _DEFAULT_URL
-        self._auth_token = auth_token
+        self._base_url = inspector_url
 
         if session is None:
-            if auth_token:
-                LOG.warning(_LW('Passing auth_token to client objects '
-                                'is deprecated, please pass session instead'))
-                auth = token_endpoint.Token(endpoint=self._base_url,
-                                            token=auth_token)
-            else:
-                auth = None
-
-            self._session = ks_session.Session(auth)
+            self._session = ks_session.Session(None)
         else:
             self._session = session
             if not inspector_url:
@@ -122,11 +149,21 @@ class BaseClient(object):
                     self._base_url = session.get_endpoint(
                         service_type=service_type,
                         interface=interface,
-                        region_name=region_name) or _DEFAULT_URL
-                except ks_exc.EndpointNotFound:
-                    LOG.warning(_LW('Endpoint for service %s was not found, '
-                                    'falling back to local host on port 5050'),
-                                service_type)
+                        region_name=region_name)
+                except ks_exc.CatalogException as exc:
+                    LOG.error('%(iface)s endpoint for %(stype)s in region '
+                              '%(region)s was not found in the service '
+                              'catalog: %(error)s',
+                              {'iface': interface,
+                               'stype': service_type,
+                               'region': region_name,
+                               'error': exc})
+                    raise EndpointNotFound(service_type=service_type)
+
+        if not self._base_url:
+            # This handles the case when session=None and no inspector_url is
+            # provided, as well as keystoneauth plugins that may return None.
+            raise EndpointNotFound(service_type=service_type)
 
         self._base_url = self._base_url.rstrip('/')
         self._api_version = self._check_api_version(api_version)
@@ -143,7 +180,7 @@ class BaseClient(object):
     def _check_api_version(self, api_version):
         if isinstance(api_version, int):
             api_version = (api_version, 0)
-        if isinstance(api_version, six.string_types):
+        if isinstance(api_version, str):
             api_version = _parse_version(api_version)
         api_version = tuple(api_version)
         if not all(isinstance(x, int) for x in api_version):
